@@ -581,7 +581,7 @@ class SubmissionService(t.Generic[_ClientT]):
         :param extra_parameters: The extra query parameters you might want to
             add. By default no extra query parameters are added.
 
-        :returns: Nothing.
+        :returns: The work of which you updated the rubric items.
         """
 
         url = "/api/v1/submissions/{submissionId}/rubricitems/".format(
