@@ -150,7 +150,6 @@ from .base_rubric_item import BaseRubricItem
 from .blackboard_zip_upload_enabled_setting import (
     BlackboardZipUploadEnabledSetting,
 )
-from .bulk_course_registration_link import BulkCourseRegistrationLink
 from .bulk_enroll_course_data import BulkEnrollCourseData
 from .canvas_course_id_copying_enabled_setting import (
     CanvasCourseIdCopyingEnabledSetting,
@@ -250,9 +249,6 @@ from .export_assignment_data import ExportAssignmentData
 from .export_assignment_files_data import ExportAssignmentFilesData
 from .extended_auto_test_result import ExtendedAutoTestResult
 from .extended_auto_test_run import ExtendedAutoTestRun
-from .extended_bulk_course_registration_link import (
-    ExtendedBulkCourseRegistrationLink,
-)
 from .extended_course import ExtendedCourse
 from .extended_course_registration_link import ExtendedCourseRegistrationLink
 from .extended_course_section import ExtendedCourseSection
@@ -400,6 +396,9 @@ from .min_password_score_setting import MinPasswordScoreSetting
 from .mirror_file_result import MirrorFileResult
 from .missing_cookie_error import MissingCookieError
 from .missing_file import MissingFile
+from .new_auto_test_allowed_initial_build_ids_setting import (
+    NewAutoTestAllowedInitialBuildIdsSetting,
+)
 from .new_auto_test_build_max_command_time_setting import (
     NewAutoTestBuildMaxCommandTimeSetting,
 )
@@ -409,6 +408,9 @@ from .new_auto_test_build_output_limit_setting import (
 from .new_auto_test_copying_enabled_setting import (
     NewAutoTestCopyingEnabledSetting,
 )
+from .new_auto_test_current_initial_build_ids_setting import (
+    NewAutoTestCurrentInitialBuildIdsSetting,
+)
 from .new_auto_test_enabled_setting import NewAutoTestEnabledSetting
 from .new_auto_test_initial_build_id_setting import (
     NewAutoTestInitialBuildIdSetting,
@@ -457,7 +459,6 @@ from .patch1_p3_provider_lti_data import Patch1P3ProviderLTIData
 from .patch_all_notification_data import PatchAllNotificationData
 from .patch_assignment_data import PatchAssignmentData
 from .patch_auto_test_data import PatchAutoTestData
-from .patch_bulk_enroll_link_course_data import PatchBulkEnrollLinkCourseData
 from .patch_comment_reply_data import PatchCommentReplyData
 from .patch_course_data import PatchCourseData
 from .patch_grader_submission_data import PatchGraderSubmissionData
@@ -490,10 +491,6 @@ from .patch_user_data import PatchUserData
 from .pay_with_coupon_course_price_data import PayWithCouponCoursePriceData
 from .peer_feedback_enabled_setting import PeerFeedbackEnabledSetting
 from .permission_exception import PermissionException
-from .personal_registration_link_info import PersonalRegistrationLinkInfo
-from .personal_registration_link_info_input_as_json import (
-    PersonalRegistrationLinkInfoInputAsJSON,
-)
 from .plagiarism_run import PlagiarismRun
 from .plagiarism_run_plagiarism_assignment_as_json import (
     PlagiarismRunPlagiarismAssignmentAsJSON,
@@ -502,7 +499,6 @@ from .plagiarism_run_plagiarism_course_as_json import (
     PlagiarismRunPlagiarismCourseAsJSON,
 )
 from .plagiarism_state import PlagiarismState
-from .post_bulk_enroll_link_course_data import PostBulkEnrollLinkCourseData
 from .post_oauth_token_data import PostOAuthTokenData
 from .present_preference import PresentPreference
 from .proxy import Proxy
@@ -516,9 +512,6 @@ from .quality_test_log import QualityTestLog
 from .quality_test_log_base import QualityTestLogBase
 from .register_enabled_setting import RegisterEnabledSetting
 from .register_user_data import RegisterUserData
-from .register_user_with_bulk_link_course_data import (
-    RegisterUserWithBulkLinkCourseData,
-)
 from .register_user_with_link_course_data import RegisterUserWithLinkCourseData
 from .release_info import ReleaseInfo
 from .release_message_max_time_setting import ReleaseMessageMaxTimeSetting
@@ -526,9 +519,6 @@ from .rename_group_group_data import RenameGroupGroupData
 from .render_html_enabled_setting import RenderHtmlEnabledSetting
 from .reset_token_time_setting import ResetTokenTimeSetting
 from .result_data_get_auto_test_get import ResultDataGetAutoTestGet
-from .result_data_get_course_get_personalized_registration_link import (
-    ResultDataGetCourseGetPersonalizedRegistrationLink,
-)
 from .result_data_get_task_result_get_all import ResultDataGetTaskResultGetAll
 from .result_data_post_login_link_login import ResultDataPostLoginLinkLogin
 from .result_data_post_user_login import ResultDataPostUserLogin
