@@ -50,8 +50,9 @@ class AllSiteSettings(FrontendSiteSettings):
     #: The max output a command from a test step is allowed to output before
     #: output is truncated.
     new_auto_test_test_output_limit: "int"
-    #: The ID of the initial base image for the code execution virtual machines
-    #: which is shared between all users.
+    #: The IDs of the available base images for AutoTest 2.0.
+    new_auto_test_allowed_initial_build_ids: "t.Sequence[str]"
+    #: Unused, use NEW\_AUTO\_TEST\_CURRENT\_INITIAL\_BUILD\_IDS.
     new_auto_test_initial_build_id: "str"
     #: The minimum strength passwords by users should have. The higher this
     #: value the stronger the password should be. When increasing the strength
@@ -207,13 +208,20 @@ class AllSiteSettings(FrontendSiteSettings):
                         " to output before output is truncated."
                     ),
                 ),
+                rqa.RequiredArgument(
+                    "NEW_AUTO_TEST_ALLOWED_INITIAL_BUILD_IDS",
+                    rqa.List(rqa.SimpleValue.str),
+                    doc=(
+                        "The IDs of the available base images for AutoTest"
+                        " 2.0."
+                    ),
+                ),
                 rqa.RequiredArgument(
                     "NEW_AUTO_TEST_INITIAL_BUILD_ID",
                     rqa.SimpleValue.str,
                     doc=(
-                        "The ID of the initial base image for the code"
-                        " execution virtual machines which is shared between"
-                        " all users."
+                        "Unused, use"
+                        " NEW\\_AUTO\\_TEST\\_CURRENT\\_INITIAL\\_BUILD\\_IDS."
                     ),
                 ),
                 rqa.RequiredArgument(
@@ -395,6 +403,9 @@ class AllSiteSettings(FrontendSiteSettings):
             "NEW_AUTO_TEST_TEST_OUTPUT_LIMIT": to_dict(
                 self.new_auto_test_test_output_limit
             ),
+            "NEW_AUTO_TEST_ALLOWED_INITIAL_BUILD_IDS": to_dict(
+                self.new_auto_test_allowed_initial_build_ids
+            ),
             "NEW_AUTO_TEST_INITIAL_BUILD_ID": to_dict(
                 self.new_auto_test_initial_build_id
             ),
@@ -443,6 +454,9 @@ class AllSiteSettings(FrontendSiteSettings):
             "AUTO_TEST_CODE_QUALITY_MESSAGE": to_dict(
                 self.auto_test_code_quality_message
             ),
+            "NEW_AUTO_TEST_CURRENT_INITIAL_BUILD_IDS": to_dict(
+                self.new_auto_test_current_initial_build_ids
+            ),
             "NEW_AUTO_TEST_BUILD_MAX_COMMAND_TIME": to_dict(
                 self.new_auto_test_build_max_command_time
             ),
@@ -593,6 +607,7 @@ class AllSiteSettings(FrontendSiteSettings):
             new_auto_test_max_file_size=parsed.NEW_AUTO_TEST_MAX_FILE_SIZE,
             new_auto_test_build_output_limit=parsed.NEW_AUTO_TEST_BUILD_OUTPUT_LIMIT,
             new_auto_test_test_output_limit=parsed.NEW_AUTO_TEST_TEST_OUTPUT_LIMIT,
+            new_auto_test_allowed_initial_build_ids=parsed.NEW_AUTO_TEST_ALLOWED_INITIAL_BUILD_IDS,
             new_auto_test_initial_build_id=parsed.NEW_AUTO_TEST_INITIAL_BUILD_ID,
             min_password_score=parsed.MIN_PASSWORD_SCORE,
             setting_token_time=parsed.SETTING_TOKEN_TIME,
@@ -617,6 +632,7 @@ class AllSiteSettings(FrontendSiteSettings):
             auto_test_checkpoint_message=parsed.AUTO_TEST_CHECKPOINT_MESSAGE,
             auto_test_unit_test_message=parsed.AUTO_TEST_UNIT_TEST_MESSAGE,
             auto_test_code_quality_message=parsed.AUTO_TEST_CODE_QUALITY_MESSAGE,
+            new_auto_test_current_initial_build_ids=parsed.NEW_AUTO_TEST_CURRENT_INITIAL_BUILD_IDS,
             new_auto_test_build_max_command_time=parsed.NEW_AUTO_TEST_BUILD_MAX_COMMAND_TIME,
             new_auto_test_test_max_command_time=parsed.NEW_AUTO_TEST_TEST_MAX_COMMAND_TIME,
             exam_login_max_length=parsed.EXAM_LOGIN_MAX_LENGTH,
