@@ -35,6 +35,13 @@ class FrontendSiteSettings:
     auto_test_unit_test_message: "str"
     #: Default message for Code Quality steps of an AutoTest.
     auto_test_code_quality_message: "str"
+    #: The IDs of the currently recent base images for AutoTest 2.0. These are
+    #: the images that we want users to use for new AutoTest 2.0
+    #: configurations. Make sure that if you add something to this list it is
+    #: also added to NEW\_AUTO\_TEST\_ALLOWED\_INITIAL\_BUILD\_IDS, as
+    #: otherwise the user is not allowed to use the image. The last item in
+    #: this list will be the default image id.
+    new_auto_test_current_initial_build_ids: "t.Sequence[str]"
     #: The maximum time a command may run in the build part of AutoTest 2.0.
     new_auto_test_build_max_command_time: "datetime.timedelta"
     #: The maximum time a command may run in the test part of AutoTest 2.0.
@@ -276,6 +283,19 @@ class FrontendSiteSettings:
                 rqa.SimpleValue.str,
                 doc="Default message for Code Quality steps of an AutoTest.",
             ),
+            rqa.RequiredArgument(
+                "NEW_AUTO_TEST_CURRENT_INITIAL_BUILD_IDS",
+                rqa.List(rqa.SimpleValue.str),
+                doc=(
+                    "The IDs of the currently recent base images for AutoTest"
+                    " 2.0. These are the images that we want users to use for"
+                    " new AutoTest 2.0 configurations. Make sure that if you"
+                    " add something to this list it is also added to"
+                    " NEW\\_AUTO\\_TEST\\_ALLOWED\\_INITIAL\\_BUILD\\_IDS, as"
+                    " otherwise the user is not allowed to use the image. The"
+                    " last item in this list will be the default image id."
+                ),
+            ),
             rqa.RequiredArgument(
                 "NEW_AUTO_TEST_BUILD_MAX_COMMAND_TIME",
                 rqa.RichValue.TimeDelta,
@@ -817,6 +837,9 @@ class FrontendSiteSettings:
             "AUTO_TEST_CODE_QUALITY_MESSAGE": to_dict(
                 self.auto_test_code_quality_message
             ),
+            "NEW_AUTO_TEST_CURRENT_INITIAL_BUILD_IDS": to_dict(
+                self.new_auto_test_current_initial_build_ids
+            ),
             "NEW_AUTO_TEST_BUILD_MAX_COMMAND_TIME": to_dict(
                 self.new_auto_test_build_max_command_time
             ),
@@ -964,6 +987,7 @@ class FrontendSiteSettings:
             auto_test_checkpoint_message=parsed.AUTO_TEST_CHECKPOINT_MESSAGE,
             auto_test_unit_test_message=parsed.AUTO_TEST_UNIT_TEST_MESSAGE,
             auto_test_code_quality_message=parsed.AUTO_TEST_CODE_QUALITY_MESSAGE,
+            new_auto_test_current_initial_build_ids=parsed.NEW_AUTO_TEST_CURRENT_INITIAL_BUILD_IDS,
             new_auto_test_build_max_command_time=parsed.NEW_AUTO_TEST_BUILD_MAX_COMMAND_TIME,
             new_auto_test_test_max_command_time=parsed.NEW_AUTO_TEST_TEST_MAX_COMMAND_TIME,
             exam_login_max_length=parsed.EXAM_LOGIN_MAX_LENGTH,
