@@ -70,8 +70,16 @@ class PartialAllSiteSettings:
     #: The max output a command from a test step is allowed to output before
     #: output is truncated.
     new_auto_test_test_output_limit: Maybe["int"] = Nothing
-    #: The ID of the initial base image for the code execution virtual machines
-    #: which is shared between all users.
+    #: The IDs of the currently recent base images for AutoTest 2.0. These are
+    #: the images that we want users to use for new AutoTest 2.0
+    #: configurations. Make sure that if you add something to this list it is
+    #: also added to NEW\_AUTO\_TEST\_ALLOWED\_INITIAL\_BUILD\_IDS, as
+    #: otherwise the user is not allowed to use the image. The last item in
+    #: this list will be the default image id.
+    new_auto_test_current_initial_build_ids: Maybe["t.Sequence[str]"] = Nothing
+    #: The IDs of the available base images for AutoTest 2.0.
+    new_auto_test_allowed_initial_build_ids: Maybe["t.Sequence[str]"] = Nothing
+    #: Unused, use NEW\_AUTO\_TEST\_CURRENT\_INITIAL\_BUILD\_IDS.
     new_auto_test_initial_build_id: Maybe["str"] = Nothing
     #: The maximum time a command may run in the build part of AutoTest 2.0.
     new_auto_test_build_max_command_time: Maybe["datetime.timedelta"] = Nothing
@@ -460,12 +468,30 @@ class PartialAllSiteSettings:
                     " output before output is truncated."
                 ),
             ),
+            rqa.OptionalArgument(
+                "NEW_AUTO_TEST_CURRENT_INITIAL_BUILD_IDS",
+                rqa.List(rqa.SimpleValue.str),
+                doc=(
+                    "The IDs of the currently recent base images for AutoTest"
+                    " 2.0. These are the images that we want users to use for"
+                    " new AutoTest 2.0 configurations. Make sure that if you"
+                    " add something to this list it is also added to"
+                    " NEW\\_AUTO\\_TEST\\_ALLOWED\\_INITIAL\\_BUILD\\_IDS, as"
+                    " otherwise the user is not allowed to use the image. The"
+                    " last item in this list will be the default image id."
+                ),
+            ),
+            rqa.OptionalArgument(
+                "NEW_AUTO_TEST_ALLOWED_INITIAL_BUILD_IDS",
+                rqa.List(rqa.SimpleValue.str),
+                doc="The IDs of the available base images for AutoTest 2.0.",
+            ),
             rqa.OptionalArgument(
                 "NEW_AUTO_TEST_INITIAL_BUILD_ID",
                 rqa.SimpleValue.str,
                 doc=(
-                    "The ID of the initial base image for the code execution"
-                    " virtual machines which is shared between all users."
+                    "Unused, use"
+                    " NEW\\_AUTO\\_TEST\\_CURRENT\\_INITIAL\\_BUILD\\_IDS."
                 ),
             ),
             rqa.OptionalArgument(
@@ -1180,6 +1206,12 @@ class PartialAllSiteSettings:
         self.new_auto_test_test_output_limit = maybe_from_nullable(
             self.new_auto_test_test_output_limit
         )
+        self.new_auto_test_current_initial_build_ids = maybe_from_nullable(
+            self.new_auto_test_current_initial_build_ids
+        )
+        self.new_auto_test_allowed_initial_build_ids = maybe_from_nullable(
+            self.new_auto_test_allowed_initial_build_ids
+        )
         self.new_auto_test_initial_build_id = maybe_from_nullable(
             self.new_auto_test_initial_build_id
         )
@@ -1472,6 +1504,14 @@ class PartialAllSiteSettings:
             res["NEW_AUTO_TEST_TEST_OUTPUT_LIMIT"] = to_dict(
                 self.new_auto_test_test_output_limit.value
             )
+        if self.new_auto_test_current_initial_build_ids.is_just:
+            res["NEW_AUTO_TEST_CURRENT_INITIAL_BUILD_IDS"] = to_dict(
+                self.new_auto_test_current_initial_build_ids.value
+            )
+        if self.new_auto_test_allowed_initial_build_ids.is_just:
+            res["NEW_AUTO_TEST_ALLOWED_INITIAL_BUILD_IDS"] = to_dict(
+                self.new_auto_test_allowed_initial_build_ids.value
+            )
         if self.new_auto_test_initial_build_id.is_just:
             res["NEW_AUTO_TEST_INITIAL_BUILD_ID"] = to_dict(
                 self.new_auto_test_initial_build_id.value
@@ -1790,6 +1830,8 @@ class PartialAllSiteSettings:
             new_auto_test_max_file_size=parsed.NEW_AUTO_TEST_MAX_FILE_SIZE,
             new_auto_test_build_output_limit=parsed.NEW_AUTO_TEST_BUILD_OUTPUT_LIMIT,
             new_auto_test_test_output_limit=parsed.NEW_AUTO_TEST_TEST_OUTPUT_LIMIT,
+            new_auto_test_current_initial_build_ids=parsed.NEW_AUTO_TEST_CURRENT_INITIAL_BUILD_IDS,
+            new_auto_test_allowed_initial_build_ids=parsed.NEW_AUTO_TEST_ALLOWED_INITIAL_BUILD_IDS,
             new_auto_test_initial_build_id=parsed.NEW_AUTO_TEST_INITIAL_BUILD_ID,
             new_auto_test_build_max_command_time=parsed.NEW_AUTO_TEST_BUILD_MAX_COMMAND_TIME,
             new_auto_test_test_max_command_time=parsed.NEW_AUTO_TEST_TEST_MAX_COMMAND_TIME,
