@@ -147,6 +147,9 @@ from .metric_gathering_time_interval_setting import (
     MetricGatheringTimeIntervalSetting,
 )
 from .min_password_score_setting import MinPasswordScoreSetting
+from .new_auto_test_allowed_initial_build_ids_setting import (
+    NewAutoTestAllowedInitialBuildIdsSetting,
+)
 from .new_auto_test_build_max_command_time_setting import (
     NewAutoTestBuildMaxCommandTimeSetting,
 )
@@ -156,6 +159,9 @@ from .new_auto_test_build_output_limit_setting import (
 from .new_auto_test_copying_enabled_setting import (
     NewAutoTestCopyingEnabledSetting,
 )
+from .new_auto_test_current_initial_build_ids_setting import (
+    NewAutoTestCurrentInitialBuildIdsSetting,
+)
 from .new_auto_test_enabled_setting import NewAutoTestEnabledSetting
 from .new_auto_test_initial_build_id_setting import (
     NewAutoTestInitialBuildIdSetting,
@@ -221,6 +227,8 @@ SiteSettingInput = t.Union[
     NewAutoTestMaxFileSizeSetting,
     NewAutoTestBuildOutputLimitSetting,
     NewAutoTestTestOutputLimitSetting,
+    NewAutoTestCurrentInitialBuildIdsSetting,
+    NewAutoTestAllowedInitialBuildIdsSetting,
     NewAutoTestInitialBuildIdSetting,
     NewAutoTestBuildMaxCommandTimeSetting,
     NewAutoTestTestMaxCommandTimeSetting,
@@ -322,6 +330,8 @@ SiteSettingInputParser = rqa.Lazy(
         ParserFor.make(NewAutoTestMaxFileSizeSetting),
         ParserFor.make(NewAutoTestBuildOutputLimitSetting),
         ParserFor.make(NewAutoTestTestOutputLimitSetting),
+        ParserFor.make(NewAutoTestCurrentInitialBuildIdsSetting),
+        ParserFor.make(NewAutoTestAllowedInitialBuildIdsSetting),
         ParserFor.make(NewAutoTestInitialBuildIdSetting),
         ParserFor.make(NewAutoTestBuildMaxCommandTimeSetting),
         ParserFor.make(NewAutoTestTestMaxCommandTimeSetting),
