@@ -9,8 +9,10 @@ from dataclasses import dataclass, field
 import cg_request_args as rqa
 from httpx import Response
 
+from .. import parsers
 from ..utils import to_dict
 from .base_error import BaseError
+from .weak_password_feedback import WeakPasswordFeedback
 
 
 @dataclass
@@ -18,7 +20,7 @@ class WeakPasswordException(BaseError):
     """Exception raised when a password is too weak to be used."""
 
     #: The feedback on how to improve the password.
-    feedback: "str"
+    feedback: "WeakPasswordFeedback"
 
     raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)
 
@@ -27,7 +29,7 @@ class WeakPasswordException(BaseError):
             rqa.FixedMapping(
                 rqa.RequiredArgument(
                     "feedback",
-                    rqa.SimpleValue.str,
+                    parsers.ParserFor.make(WeakPasswordFeedback),
                     doc="The feedback on how to improve the password.",
                 ),
             )
